<?php
/*
Plugin Name: Post Editor Buttons Fork
Plugin URI: http://trepmal.com/plugins/post-editor-buttons-fork/
Description: This plugin allows you to add buttons to the HTML post editor.
Version: 2.1
Author: Kailey Lampert
Author URI: http://kaileylampert.com
Original: Oren Yomtom
*/
/*
    Copyright (C) 2011  Kailey Lampert

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

	add_action('init', 'peb_init');
	/**
	 * Get hooked in
	 *
	 * @return void
	 */
	function peb_init() {
		add_filter('admin_init', 'peb_reg_settings');
		add_action('admin_print_scripts-post.php', 'peb_admin_head_post');
		add_action('admin_print_scripts-post-new.php', 'peb_admin_head_post');
		add_action('admin_menu', 'peb_config_page');
		add_filter('plugin_action_links', 'peb_actions', 10, 2 );
	}
	/**
	 * Register options
	 *
	 * @return void
	 */
	function peb_reg_settings() {
		register_setting( 'peb', 'peb_caption', 'esc_attr_array' );
		register_setting( 'peb', 'peb_before', 'wp_filter_post_kses_array' );
		register_setting( 'peb', 'peb_after', 'wp_filter_post_kses_array' );
	}
	/**
	 * Apply esc_attr to an array
	 *
	 * @param array $input
	 * @return array
	 */
	function esc_attr_array( $input ) {
		return array_map( 'esc_attr', $input);
	}
	/**
	 * Apply wp_filter_post_kses to an array
	 * Apply peb_quote_replace to an array
	 *
	 * @param array $input
	 * @return array
	 */
	function wp_filter_post_kses_array( $input ) {
		$input = array_map( 'peb_quote_replace', $input);
		return array_map( 'wp_filter_post_kses', $input);
	}
	/**
	 * Replace " with ' in array
	 *
	 * @param array $input
	 * @return array
	 */
	function peb_quote_replace( $input ) {
		return str_replace('"', "'", $input );
	}
	/**
	 * Load our custom JS
	 *
	 * @return void
	 */
	function peb_admin_head_post() {
		wp_enqueue_script('expand_quicktags', admin_url('options-general.php?page=peb.js', __FILE__), array( 'quicktags') );
	}
	/**
	 * Create menu items
	 *
	 * Create PEB configuration menu item
	 * Create PEB JS menu item
	 * Remove PEB JS menu item - page can still be accessed directly, but it won't be listed in the menu
	 * @return void
	 */
	function peb_config_page() {
		$page = add_options_page('PEB Options', 'Post Editor Buttons', 'administrator', 'peb', 'peb_conf');
		add_action('admin_print_scripts-'.$page, 'peb_admin_head_admin');
		//add_contextual_help( $page, peb_help() );
		$js = add_options_page('PEB JS', 'PEB JS', 'read', 'peb.js', 'peb_conf' );
		add_action('load-'.$js, 'peb_admin_head_admin_js');
		remove_submenu_page( 'options-general.php', 'peb.js' );
	}
	/**
	 * Show all allowed tags and attributes
	 *
	 * @return string HTML
	 */
	function peb_help() {
		global $allowedposttags;
		$help = '<h3>Allowed attributes by tag</h3><ul style="width:49%;float:left;">';
		$half = round( count( $allowedposttags )/2 );
		$i = 1;
		foreach( $allowedposttags as $tag => $atts ) {
			$atts = array_keys($atts);
			$help .= '<li><strong>'.$tag.':</strong> '.implode(', ', $atts) .'</li>';
			if ($half == $i) $help .= '</ul><ul style="width:49%;float:right;">';
			++$i;
		}
		$help .= '</ul><div style="clear:both;"></div>';
		return $help;
	}
	/**
	 * Write the Custom JS to the hidden page
	 *
	 * This method means we can use PHP in the JS
	 * It also eliminates the need to write an actual JS file
	 *
	 */
	function peb_admin_head_admin_js() {
		header('Content-type: application/js');
		if ($_GET['page'] == 'peb.js') {
			$caption = get_option('peb_caption');
			$before = get_option('peb_before');
			$after = get_option('peb_after');
			foreach ($caption as $id=>$val ) {
				if ( empty( $caption[ $id ] ) ) continue;
				echo 'edButtons[edButtons.length]=new edButton("peb_'. $id .'","'. str_replace('"','&quot;',$caption[$id]) .'","'. str_replace('"','\"',$before[$id]) .'","'. str_replace('"','\"',$after[$id]) .'","'. str_replace('"','&quot;',$caption[$id]) .'");'."\n";
			}
			die();
		}
	}
	/**
	 * Load JS for the configuration page
	 *
	 * @return void
	 */
	function peb_admin_head_admin() {
		wp_enqueue_script('manage_quicktag_rows', plugins_url('mng_rows.js', __FILE__) );
	}
	/**
	 * Add a 'Use' button to the links row on plugins.php
	 *
	 * Links to the PEB's configuration page
	 *
	 * @return void
	 */
	function peb_actions($links, $file){
		$this_plugin = plugin_basename(__FILE__);
		if ( $file == $this_plugin ){
			$settings_link = '<a href="'. admin_url( 'options-general.php?page=peb' ) .'">' . __('Use') . '</a>';
			array_unshift($links, $settings_link);
		}
		return $links;
	}
	/**
	 * The configuration page
	 *
	 */
	function peb_conf() {
		?>
		<div class="wrap">
		<h2>Post Editor Buttons</h2>
		<form method="post" action="options.php">
		<?php wp_nonce_field('peb-options'); ?>
		<table class="form-table" id="op_table">
		<tr valign="top">
			<th scope="row">Caption</th>
			<th scope="row">Before</th>
			<th scope="row">After</th>
			<th scope="row">Delete</th>
		</tr>
		<tr valign="top">
			<td><input type="text" readonly value="H3" /></td>
			<td><input type="text" readonly value="<?php echo htmlentities( '<h3>' ); ?>" /></td>
			<td><input type="text" readonly value="<?php echo htmlentities( '</h3>' ); ?>" /></td>
			<td>&larr; Example</td>
		</tr>
		<?php
			$caption = get_option('peb_caption');
			$before = get_option('peb_before');
			$after = get_option('peb_after');

			for ( $i = 0; $i < count( $caption ); $i++ ) {
				?>
				<tr valign="top" id="row<?php echo $i; ?>">
				<td><input type="text" name="peb_caption[]" value="<?php echo stripslashes( htmlentities($caption[$i])); ?>" /></td>
				<td><input type="text" name="peb_before[]" value="<?php echo stripslashes( htmlentities($before[$i])); ?>" /></td>
				<td><input type="text" name="peb_after[]" value="<?php echo stripslashes( htmlentities($after[$i])); ?>" /></td>
				<td><a  href="#" onclick="return peb_deleteRow('<?php echo $i; ?>');"><?php echo _e('Delete') ?></a></td>
				</tr>
				<?php
			}
		?>
		</form>
		<table class="form-table">
		<tr valign="top">
			<td>
			<p><a href="#" onclick="return peb_addMore();"><?php echo _e('New') ?></a></p>
			<input type="hidden" name="option_page" value="peb" />
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="page_options" value="peb_caption,peb_before,peb_after" />
			<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" /> Be sure to hit save after deleting any rows.</p>
			<p>Remember, these buttons will only be added to the HTML view of the editor.</p>
			</td>
		</tr>
		</table>
		</form>
		</div>
		<?php
	}